cli - Snailz Docs

Skip to content

# cli

Entry point for command-line interface.

Usage:

    cli [OPTIONS] COMMAND [ARGS]...

Options:

      --help  Show this message and exit.

## data

Generate and save data using provided parameters.

Usage:

    cli data [OPTIONS]

Options:

      --csvdir PATH  Path to CSV directory
      --params PATH  Path to parameters file  [required]
      --output PATH  Path to output file
      --help         Show this message and exit.

## params

Generate and save parameters.

Usage:

    cli params [OPTIONS]

Options:

      --output PATH  Path to output file
      --help         Show this message and exit.